@@ -28,7 +28,7 @@
 #include "m_string.h"
 #include "my_byteorder.h"
 
-#ifndef NDEBUG
+#if !defined(NDEBUG) && defined(HAVE_MYSYS)
 /* Event parser state names */
 static const char *event_parser_state_names[] = {"None", "GTID", "DDL", "DML",
                                                  "Error"};
@@ -245,6 +245,7 @@ Transaction_boundary_parser::get_event_boundary_type(
     case binary_log::ROTATE_EVENT:
     case binary_log::FORMAT_DESCRIPTION_EVENT:
     case binary_log::HEARTBEAT_LOG_EVENT:
+    case binary_log::HEARTBEAT_LOG_EVENT_V2:
     case binary_log::PREVIOUS_GTIDS_LOG_EVENT:
     case binary_log::STOP_EVENT:
     case binary_log::SLAVE_EVENT:
