@@ -196,6 +196,11 @@ static void notify_session_disconnect_noop(PSI_thread *) { return; }
 
 static void notify_session_change_user_noop(PSI_thread *) { return; }
 
+static void set_mem_cnt_THD_noop(THD *, THD **backup_thd) {
+  *backup_thd = nullptr;
+  return;
+}
+
 static PSI_thread_service_t psi_thread_noop = {
     register_thread_noop,
     spawn_thread_noop,
@@ -233,7 +238,8 @@ static PSI_thread_service_t psi_thread_noop = {
     unregister_notification_noop,
     notify_session_connect_noop,
     notify_session_disconnect_noop,
-    notify_session_change_user_noop};
+    notify_session_change_user_noop,
+    set_mem_cnt_THD_noop};
 
 struct PSI_thread_bootstrap *psi_thread_hook = nullptr;
 PSI_thread_service_t *psi_thread_service = &psi_thread_noop;
